/*$Id:$*/
/*16.01.2022	16.01.2022	Белых А.И.	xmurndsopw.h
Реквизиты поиска для отчёта "Распределение НДС по видам операций
*/

class xmurndsop_rp
 {
  public:
   class iceb_u_str datan;
   class iceb_u_str datak;
   class iceb_u_str sklad;
   int prih_rash; /* 0 все 1 приход 2 расход*/
   class iceb_u_str kod_op;
   class iceb_u_str kod_kontr;
   class iceb_u_str nom_dok;   

   xmurndsop_rp()
    {
     clear();
    }
   void clear()
    {
     datan.new_plus("");
     datak.new_plus("");
     sklad.new_plus("");
     prih_rash=0;
     kod_op.new_plus("");
     kod_kontr.new_plus("");
     nom_dok.new_plus("");
    }   
 };
