/*$Id:$*/
/*26.08.2021	26.08.2021	Белых А.И.	iceb_zagacts.cpp
Шапка акта сверки
*/
#include "iceb_libbuh.h"


void iceb_zagacts(short dn,short mn,short gn,
short dk,short mk,short gk,
const char *kodkontr,const char *naimkont,FILE *ff)
{
time_t vrem;
struct tm *bf;
char bufer[1024];

time(&vrem);
bf=localtime(&vrem);

fprintf(ff,gettext("\
                                       АКТ СВЕРКИ ВЗАИМНЫХ РАСЧЕТОВ\n\n\
   Мы ниже подписавшиеся, главный бухгалтер %s\n\
________________________________________________________________________________________________________\n\
                    (наименование учереждения, фамилия и инициалы)\n\
и главный бухгалтер %s\n\
_________________________________________________________________________________________________________\n\
                   (наименование учереждения, фамилия и инициалы)\n\
составили настоящий акт о том, что проведена проверка взаимных расчётов\n"),
iceb_get_pnk("00",0,NULL),naimkont);

fprintf(ff,"%s %02d.%02d.%d%s %s %02d.%02d.%d%s\n",
gettext("За период с"),
dn,mn,gn,
gettext("г."),
gettext("по"),
dk,mk,gk,
gettext("г."));
/**********
fprintf(ff,"%s:%02d.%02d.%d %s\n\n",
gettext("По состоянию на"),
d,m,g,gettext("г."));
************/
fprintf(ff,"%s:%02d.%02d.%d %s\n\n",
gettext("По состоянию на"),
bf->tm_mday,bf->tm_mon+1,bf->tm_year+1900,gettext("г."));

fprintf(ff,"%s:\n",gettext("При проверке установлено"));

sprintf(bufer,"%s %s",
gettext("По"),
iceb_get_pnk("00",0,NULL));

fprintf(ff,"\
%-*s %s %s %s\n",
iceb_u_kolbait(55,bufer),
bufer,
gettext("По"),
kodkontr,naimkont);



}
