/*$Id:$*/
/*23.12.2025	22.12.2025	Белых А.И.	iceb_printw_from_thread.h
Структура с данными для передачи в подпрограмму
*/

class iceb_printw_from_thread_data
 {
  public:

// Очередь и мьютекс для безопасной передачи строк между потоками
   GQueue* text_queue;
   GMutex  queue_mutex;

   GtkWidget *view;
   char *str;

   iceb_printw_from_thread_data()
    {
/*********************
  Если переменная a GMutex помещена в другой контекст (например, встроена в структуру),
   то её необходимо явно инициализировать с помощью функции 


Чтобы отменить действие g_mutex_init() мьютекса, когда он больше не нужен,
 используйте функцию g_mutex_clear().


****************/
     g_mutex_init(&queue_mutex);
    }
 };
 
