/*$Id:$*/
/*28.08.2021	02.03.2008	Белых А.И.	iceb_salorok.c
Расчёт сальдо по контрагенту
*/

#include "iceb_libbuh.h"
#include "iceb_salorok.h"

int iceb_salorok_m(class iceb_salorok_data *rek_ras,GtkWidget *wpredok);
int iceb_salorok_r(class iceb_salorok_data *datark,class spis_oth *oth,GtkWidget *wpredok);

void iceb_salorok(const char *kontr,GtkWidget *wpredok)
{


static class iceb_salorok_data data;

if(kontr[0] != '\0')
 data.kodo.new_plus(kontr);

class spis_oth oth;

if(iceb_salorok_m(&data,wpredok) != 0)
 return;

if(iceb_salorok_r(&data,&oth,wpredok) != 0)
 return;

iceb_rabfil(&oth,wpredok);


}

