/*$Id: iceb_salorok.h,v 1.2 2011-01-13 13:49:59 sasa Exp $*/
/*28.08.2021	27.02.2008	Белых А.И.	iceb_salorok.h
Реквизиты для расчёта реестра проводок по видам операций
*/

class iceb_salorok_data
 {
  public:
   class iceb_u_str datan;
   class iceb_u_str datak;
   class iceb_u_str kodo;
   class iceb_u_str sheta;
   class iceb_u_str sheta_kor;
   int par; /*0-все проводки 1-без взаимоно кореспондерующих*/
   
   class spis_oth *oth;   
   
   iceb_salorok_data()
    {
     clear();
    }   

   void clear()
    {
     par=0;
     sheta.new_plus("");
     sheta_kor.new_plus("");
     kodo.new_plus("");
     datan.new_plus("");
     datak.new_plus("");
    }

 };
