/*$Id: koncinvw.c,v 1.10 2014/02/28 05:20:59 sasa Exp $*/
/*11.07.2015	10.08.2003	Белых А.И. 	koncinvw.c
Концовка инвентаризационной ведемоти
*/
#include "buhg_g.h"


void koncinvw(const char *mesqc,short gos,FILE *ff2)
{
iceb_insfil("inved_end.alx",ff2,NULL);

}
