/*$Id: opssw.c,v 1.8 2013/08/13 06:09:47 sasa Exp $*/
/*22.06.2022	09.05.2005	Белых А.И.	opssw.c
Расчёт по счётам списания материалов
*/


#include "buhg_g.h"
#include "opssw.h"

int opssw_m(class opss_poi *rek_ras);
int opssw_r(class opss_poi *datark,class spis_oth *oth,GtkWidget *wpredok);

void opssw()
{
static class opss_poi data;
class spis_oth oth;

if(opssw_m(&data) != 0)
 return;
printf("%s\n",__FUNCTION__);

if(opssw_r(&data,&oth,NULL) != 0)
 return;
iceb_rabfil(&oth,NULL);

}
