/*$Id: hrvnks.c,v 1.5 2013/08/13 06:09:34 sasa Exp $*/
/*10.07.2015	28.08.2003	Белых А.И.	hrvnks.c
Шапка 
*/
#include "buhg_g.h"
void	hrvnks(FILE *ff,int *kolstrok)
{
*kolstrok=6;
fprintf(ff,"\
                        С П И С О К   N     від\n\
на зарахування ________________ робітникам %s\n\
      за            перерахованої на карткові рахунки в філію\n\
   \"Вінницьке Центральне відділення ПАТ Промінвестбанк\"\n\
    згідно платіжного доручення N____ від ______________р.\n\n",
iceb_get_pnk("00",0,NULL));

}
