/*$Id: r_poiprov.c,v 1.34 2013/09/26 09:46:53 sasa Exp $*/
/*28.12.2021	19.01.2004	Белых А.И.	r_poiprov.c
Распечатка найденных проводок из режима поиска проводок
*/
#include <errno.h>
#include "buhg_g.h"
#include "prov_poi.h"

extern SQL_baza	bd;
int rasprovw(class SQLCURSOR *cur,int kolstr,class prov_poi_data *poi,class spis_oth *oth,GtkWidget *bar,GtkWidget *wpredok);

int r_poiprov(class prov_poi_data *rekv_m_poiprov,class spis_oth *oth,GtkWidget *wpredok)
{
class iceb_gdite_data gdite;
iceb_gdite(&gdite,0,wpredok);
int kolstr=0;
class SQLCURSOR cur;

if((kolstr=cur.make_cursor(&bd,rekv_m_poiprov->zapros.ravno())) < 0)
 {
  iceb_msql_error(&bd,gettext("Ошибка создания курсора !"),rekv_m_poiprov->zapros.ravno(),wpredok);
  return(1);
 }


return(rasprovw(&cur,kolstr,rekv_m_poiprov,oth,gdite.bar,wpredok));


}

