/*$Id: iceb_get_namebase.c,v 1.2 2013/05/17 14:58:34 sasa Exp $*/
/*19.09.2011	19.09.2011	Белых А.И.	iceb_get_namebase.c
Получение имени базы данных
*/

extern char *imabaz;

const char *iceb_get_namebase()
{
return(imabaz);
}
