/*$Id:$*/
/*26.08.2021	26.08.2021	Белых А.И.	iceb_konact.cpp
Концовка акта сверки
*/
#include "iceb_libbuh.h"

void iceb_konact(FILE *ff,GtkWidget *wpredok)
{
fprintf(ff,"\n");
fprintf(ff,gettext("\
После отражения в учете указанных дополнительных проводок сальдо на ________________________\n\
выражается в сумме__________________________________________________________________________\n\
____________________________________________________________________________________________\n\
                  (сумма прописью и цифрами)\n\
в пользу____________________________________________________________________________________\n\
                   (Указать наименование учереждения)\n\n"));


fprintf(ff,"\
%*s________________________    %*s________________________\n\n",
iceb_u_kolbait(25,gettext("Руководитель")),
gettext("Руководитель"),
iceb_u_kolbait(25,gettext("Руководитель")),
gettext("Руководитель"));


fprintf(ff,"\
%*s________________________    %*s________________________\n",
iceb_u_kolbait(25,gettext("Главный бухгалтер")),
gettext("Главный бухгалтер"),
iceb_u_kolbait(25,gettext("Главный бухгалтер")),
gettext("Главный бухгалтер"));

                                     
fprintf(ff,"\n");

SQL_str row;
SQLCURSOR cur;
class iceb_u_str telef("");
if(iceb_sql_readkey("select telef from Kontragent where kodkon='00'",&row,&cur,wpredok) == 1)
 telef.new_plus(row[0]);

fprintf(ff,gettext("\
Вышлите нам, пожалуйста, один экземпляр акта с Вашими подписью и печатью.\n\
В случае несоответствия сумм, просим выслать розшифровку или провести сверку\n\
по телефону"));

fprintf(ff," %s\n",telef.ravno()); 

fprintf(ff,gettext("\
Просим в течении 5 дней вернуть подписанный акт.\n\
При невозвращении акта, сумма будет зачтена, как согласованная."));

iceb_podpis(ff,wpredok);

}
