/*$Id:$*/
/*28.08.2021	28.08.2021	Белых А.И.	iceb_zagsh.cpp
Заголовок акта сверки
*/
#include "iceb_libbuh.h"
extern SQL_baza bd;

void iceb_zagsh(const char *shet,FILE *ff,GtkWidget *wpredok)
{
char	strsql[512];
SQL_str row;
SQLCURSOR cur;
class iceb_u_str naim("");
if(shet[0] != '\0')
 {
 
  sprintf(strsql,"select nais from Plansh where ns='%s'",shet);
  if(sql_readkey(&bd,strsql,&row,&cur) == 1)
   naim.new_plus(row[0]);
 
  fprintf(ff,"\n%s:%s %s\n",gettext("Счет"),shet,naim.ravno());
 }
 
fprintf(ff,"\
------------------------------------------------------ ---------------------------------------------------\n");
fprintf(ff,gettext("\
  Дата    |   Коментарий       | Дебет    | Кредит   | |  Дата    |   Коментарий       |  Дебет | Кредит |\n"));

fprintf(ff,"\
------------------------------------------------------ ---------------------------------------------------\n");

}
