/*$Id:$*/
/*16.01.2022	16.01.2022	Белых А.И.	xmurndsopw.c
Расчёт распределения НДС по видам операций
*/


#include "buhg_g.h"
#include "xmurndsopw.h"

int xmurndsopw_m(class xmurndsop_rp *rp);
int xmurndsopw_r(class xmurndsop_rp *rp,class spis_oth *oth,GtkWidget *wpredok);

void xmurndsopw()
{
static class xmurndsop_rp data;

class spis_oth oth;

if(xmurndsopw_m(&data) != 0)
 return;

if(xmurndsopw_r(&data,&oth,NULL) != 0)
 return;

iceb_rabfil(&oth,NULL);

}
