/*$Id: iceb_u_kol_str_l.c,v 1.3 2013/05/17 14:58:42 sasa Exp $*/
/*12.03.2005	12.03.2005	Белых А.И.	iceb_u_kol_str_l.c
Расчёт количества строк для ландшафтной ориентации,
которое может поместиться на листе для нестандартных листов
возвращает количество строк
*/
#include        <math.h>

int iceb_u_kol_str_l(int max_kol_std_na_liste, //максимальное количество строк на нестандартном листе при нормальном межстрочном расстоянии
int ras_kol_str) //максимальное количество строк на стандартном листе которое помещается с уменьшением межсторочного расстояния
{

double bb=((double)ras_kol_str/47.)*max_kol_std_na_liste;
double kolstr=0.;

modf(bb,&kolstr);
return((int)kolstr);
}

