/*$Id:$*/
/*11.10.2024	10.10.2024	Белых А.И.	zar_get_pvsw.cpp
Поличение процента военного сбора
*/
#include "buhg_g.h"

extern class iceb_u_str kod_zv_gr; /*коды званий гражданских*/

double zar_get_pvsw(short dn,short mn,short gn,int zvan)
{
char strsql[1024];
double proc=1.5;

if(kod_zv_gr.ravno()[0] != '\0')
if(iceb_u_proverka(kod_zv_gr.ravno(),zvan,0,1) != 0) /*для военных в тылу остался 1.5 прос. для военных на фронте не начиляется*/
 {
  
  sprintf(strsql,"%s-Военный поэтому процент %.2f kod_zv_gr=%s zvan=%d\n",__FUNCTION__,proc,kod_zv_gr.ravno(),zvan);
  zar_pr_insw(strsql,NULL);
 
  return(proc);
 }


if(iceb_u_sravmydat(dn,mn,gn,1,12,2024) >= 0)
 proc=5.;

return(proc);
}
