/*$Id: glk_ospsw_r.c,v 1.49 2014/08/31 06:19:20 sasa Exp $*/
/*28.07.2023	28.073.2023	Белых А.И.	glk_ospsw_r.c
Расчёт отчёта 
*/
#include <errno.h>
#include "buhg_g.h"
#include "math.h"

class glk_ospsw_r_data
 {

  public:

  GtkWidget *knopka;
  GtkWidget *window;
  GtkWidget *label;
  GtkWidget *bar;
  GtkWidget *view;
  GtkTextBuffer *buffer;
  class iceb_u_str name_window;

  short kon_ras; //0-расчёт завершен 1-нет
  class iceb_u_str data_s;
  int voz;

  glk_ospsw_r_data()
   {
    voz=1;
    kon_ras=1;
   }
 };
gboolean   glk_ospsw_r_key_press(GtkWidget *widget,GdkEventKey *event,class glk_ospsw_r_data *data);
gint glk_ospsw_r1(class glk_ospsw_r_data *data);
void  glk_ospsw_r_v_knopka(GtkWidget *widget,class glk_ospsw_r_data *data);


extern SQL_baza bd;
extern int      kol_strok_na_liste;
extern short startgodb; /*Стартовый год главной книги*/

int glk_ospsw_r(const char *data_s,GtkWidget *wpredok)
{
char strsql[512];
int gor=0;
int ver=0;
class iceb_u_str repl;
class glk_ospsw_r_data data;

data.data_s.new_plus(data_s);
data.name_window.plus(__FUNCTION__);

data.window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
gtk_window_set_modal(GTK_WINDOW(data.window),TRUE);
gtk_window_set_position( GTK_WINDOW(data.window),ICEB_POS_CENTER);
if(iceb_sizwr(data.name_window.ravno(),&gor,&ver) == 0)
   gtk_window_set_default_size (GTK_WINDOW  (data.window),gor,ver);
else
  gtk_window_set_default_size (GTK_WINDOW  (data.window),400,400);

sprintf(strsql,"%s %s",iceb_get_namesystem(),gettext("Распечатка списка документов"));
gtk_window_set_title(GTK_WINDOW(data.window),strsql);

g_signal_connect(data.window,"delete_event",G_CALLBACK(gtk_widget_destroy),NULL);
g_signal_connect(data.window,"destroy",G_CALLBACK(gtk_main_quit),NULL);
g_signal_connect_after(data.window,"key_press_event",G_CALLBACK(glk_ospsw_r_key_press),&data);

if(wpredok != NULL)
 {
  gdk_window_set_cursor(gtk_widget_get_window(wpredok),gdk_cursor_new_for_display(gtk_widget_get_display(wpredok),ICEB_CURSOR_GDITE));
  //Удерживать окно над породившем его окном всегда
  gtk_window_set_transient_for(GTK_WINDOW(data.window),GTK_WINDOW(wpredok));
  //Закрыть окно если окно предок удалено
  gtk_window_set_destroy_with_parent(GTK_WINDOW(data.window),TRUE);
 }

GtkWidget *vbox=gtk_box_new(GTK_ORIENTATION_VERTICAL, 2);
gtk_box_set_homogeneous (GTK_BOX(vbox),FALSE); //Устанавливает одинакоый ли размер будут иметь упакованные виджеты-TRUE-одинаковые FALSE-нет

gtk_container_add(GTK_CONTAINER(data.window), vbox);

data.label=gtk_label_new(gettext("Ждите !!!"));

gtk_box_pack_start(GTK_BOX(vbox),data.label,FALSE,FALSE,0);

repl.plus(gettext("Распечатка списка документов"));
sprintf(strsql,"%s:%s %s\n",gettext("База данных"),iceb_get_namebase(),iceb_get_pnk("00",0,wpredok));
repl.ps_plus(strsql);

GtkWidget *label=gtk_label_new(repl.ravno());

gtk_box_pack_start(GTK_BOX(vbox),label,FALSE,FALSE,0);

data.view=gtk_text_view_new();

gtk_text_view_set_editable(GTK_TEXT_VIEW(data.view),FALSE); //Запрет на редактирование текста

data.buffer=gtk_text_view_get_buffer(GTK_TEXT_VIEW(data.view));

GtkWidget *sw=gtk_scrolled_window_new(NULL,NULL);
gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),GTK_POLICY_AUTOMATIC,GTK_POLICY_AUTOMATIC);
gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
gtk_container_add(GTK_CONTAINER(sw),data.view);


data.bar=gtk_progress_bar_new();
gtk_progress_bar_set_show_text(GTK_PROGRESS_BAR(data.bar),TRUE); /*Показывать текст в строке*/



gtk_box_pack_start (GTK_BOX (vbox), data.bar, FALSE, FALSE, 2);



sprintf(strsql,"F10 %s",gettext("Выход"));
data.knopka=gtk_button_new_with_label(strsql);
gtk_widget_set_tooltip_text(data.knopka,gettext("Завершение работы в этом окне"));
g_signal_connect(data.knopka,"clicked",G_CALLBACK(glk_ospsw_r_v_knopka),&data);
gtk_widget_set_name(data.knopka,iceb_u_inttochar(0));
gtk_box_pack_start (GTK_BOX (vbox), data.knopka, FALSE, FALSE, 2);

gtk_widget_set_sensitive(GTK_WIDGET(data.knopka),FALSE);//Недоступна

gtk_widget_show_all(data.window);


//gtk_window_set_decorated(GTK_WINDOW(data.window),FALSE); //Убирает рамку вокруг окна

//gtk_widget_set_sensitive(GTK_WIDGET(data.knopka),FALSE);//Недоступна

g_idle_add((GSourceFunc)glk_ospsw_r1,&data);

gtk_main();

if(wpredok != NULL)
  gdk_window_set_cursor(gtk_widget_get_window(wpredok),gdk_cursor_new_for_display(gtk_widget_get_display(wpredok),ICEB_CURSOR));

return(data.voz);
}

/*****************************/
/*Обработчик нажатия кнопок  */
/*****************************/
void  glk_ospsw_r_v_knopka(GtkWidget *widget,class glk_ospsw_r_data *data)
{
if(data->kon_ras == 1)
 return;
iceb_sizww(data->name_window.ravno(),data->window);
gtk_widget_destroy(data->window);
return;
}
/*********************************/
/*Обработка нажатия клавиш       */
/*********************************/

gboolean   glk_ospsw_r_key_press(GtkWidget *widget,GdkEventKey *event,class glk_ospsw_r_data *data)
{
switch(event->keyval)
 {
  case GDK_KEY_Escape:
  case GDK_KEY_F10:
    g_signal_emit_by_name(data->knopka,"clicked");
    break;
 }
return(TRUE);
}


/******************************************/
int glk_ospsw_r_saldo_sh(const char *shet,const char *data_saldo,double *debet,double *kredit,class glk_ospsw_r_data *data)
{
short ds=0,ms=0,gs=0;
char strsql[1024];
SQL_str         row;
class SQLCURSOR cur;
int kolstr=0;short godn=startgodb;
double deb=0.,kre=0.;

*debet=0.;
*kredit=0.;

sprintf(strsql,"%s:%s\n",gettext("Счёт"),shet);
iceb_printw(strsql,data->buffer,data->view);

if(iceb_prsh1(shet,data->window) != 0)
 return(1);

if(iceb_u_rsdat(&ds,&ms,&gs,data_saldo,0) != 0)
 return(1);

if(startgodb == 0 || startgodb > gs)
  godn=gs;


int vsaldo=0;
/*Узнаём наименование счёта*/
class iceb_u_str naim_shet("");
sprintf(strsql,"select nais,saldo from Plansh where ns='%s'",shet);
if(iceb_sql_readkey(strsql,&row,&cur,data->window) == 1)
 {
  naim_shet.new_plus(row[0]);
  vsaldo=atoi(row[1]);
  if(vsaldo == 3)
   {
    sprintf(strsql,"%s %s %s!",gettext("Счёт"),shet,gettext("имеет развёрнутое сальдо"));
    iceb_menu_soob(strsql,data->window);
    return(1);
   }
 }
else
 {
  sprintf(strsql,"%s %s %s!",gettext("Нет счёта"),shet,gettext("в плане счетов"));
  iceb_menu_soob(strsql,data->window);
  return(1);
 }


sprintf(strsql,"select ns,deb,kre from Saldo where kkk='0' and gs=%d and ns like '%s%%'",
godn,shet);

if((kolstr=cur.make_cursor(&bd,strsql)) < 0)
 {
  iceb_msql_error(&bd,gettext("Ошибка создания курсора !"),strsql,data->window);
  return(1);
 }

while(cur.read_cursor(&row) != 0)
 {
  deb+=atof(row[1]);
  kre+=atof(row[2]);
 }

sprintf(strsql,"%s %10.2f %10.2f\n",gettext("Стартовое сальдо"),deb,kre);
iceb_printw(strsql,data->buffer,data->view);


sprintf(strsql,"select deb,kre from Prov where val=0 and datp >= '%04d-%02d-%02d' and \
datp <= '%04d-%02d-%02d' and sh like '%s%%'",
godn,1,1,gs,ms,ds,shet);

if((kolstr=cur.make_cursor(&bd,strsql)) < 0)
 {
  iceb_msql_error(&bd,gettext("Ошибка создания курсора !"),strsql,data->window);
  return(1);
 }

while(cur.read_cursor(&row) != 0)
 {
  deb+=atof(row[0]);
  kre+=atof(row[1]);
 }

sprintf(strsql,"%s %10.2f %10.2f\n",gettext("Конечное сальдо"),deb,kre);
iceb_printw(strsql,data->buffer,data->view);

if(deb > kre)
 {
  *debet=deb-kre;
  sprintf(strsql,"%s:%10.2f\n",gettext("Дебет"),*debet);
  iceb_printw(strsql,data->buffer,data->view);
 }
else
 {
  *kredit=kre-deb;
  sprintf(strsql,"%s:%10.2f\n",gettext("Кредит"),*kredit);
  iceb_printw(strsql,data->buffer,data->view);
 }  

return(0);

}

















/******************************************/
/******************************************/

gint glk_ospsw_r1(class glk_ospsw_r_data *data)
{
time_t vremn;
time(&vremn);
char strsql[1024];
class iceb_clock sss(data->window);
class iceb_u_str kod_edr("");
SQL_str row_alx,row;
class SQLCURSOR cur_alx,cur;
int kolstr=0;
if(data->data_s.getdlinna() <= 1)
 {
  iceb_menu_soob(gettext("Не введена дата!"),data->window);
  gtk_widget_destroy(data->window);
  sss.clear_data();
  return(FALSE);
 }

if(data->data_s.prov_dat() != 0)
 {
  iceb_menu_soob(gettext("Не правильно введена дата!"),data->window);
  gtk_widget_destroy(data->window);
  sss.clear_data();
  return(FALSE);
 }


sprintf(strsql,"select str from Alx where fil='glk_osps.alx' order by ns asc");
if((kolstr=cur_alx.make_cursor(&bd,strsql)) < 0)
 {
  iceb_msql_error(&bd,gettext("Ошибка создания курсора !"),strsql,data->window);
  gtk_widget_destroy(data->window);
  sss.clear_data();
  return(FALSE);
 }

if(kolstr == 0)
 {
  iceb_menu_soob(gettext("Не найдено ни одной записи настройки!"),data->window);
  gtk_widget_destroy(data->window);
  sss.clear_data();
  return(FALSE);
 }

short dz=0,mz=0,gz=0;

iceb_u_rsdat(&dz,&mz,&gz,data->data_s.ravno(),0);

class iceb_u_str shet("");
class iceb_u_str shet_deb("");
class iceb_u_str shet_kre("");
double debet=0.,kredit=0.;
class iceb_u_str koment("");
int kolstr1=0;
int kol_prov=0;


sprintf(strsql,"DELETE FROM Prov WHERE datp='%04d-%02d-%02d' and komen like '%s%%'",gz,mz,dz,gettext("Обнуление сальдо"));

iceb_sql_zapis(strsql,1,0,data->window);

while(cur_alx.read_cursor(&row_alx) != 0)
 {
//  strzag(LINES-1,0,kolstr,++kolstr1);
  iceb_pbar(data->bar,kolstr,++kolstr1);    

  if(row_alx[0][0] == '#')
   continue;

  sprintf(strsql,"%s\n",row_alx[0]);
  iceb_printw(strsql,data->buffer,data->view);
  
  if(iceb_u_polen(row_alx[0],&shet,1,'|') != 0)
   continue;
  
  if(iceb_u_polen(row_alx[0],&shet_deb,2,'|') != 0)
   continue;

  if(iceb_u_polen(row_alx[0],&shet_kre,3,'|') != 0)
   continue;

  if(iceb_prsh1(shet.ravno(),data->window) != 0)
   continue;

  if(iceb_prsh1(shet_deb.ravno(),data->window) != 0)
   continue;
 
  if(iceb_u_SRAV(shet_deb.ravno(),shet_kre.ravno(),0) != 0)
   if(iceb_prsh1(shet_kre.ravno(),data->window) != 0)
    continue;

  sprintf(strsql,"select saldo from Plansh where ns='%s'",shet_deb.ravno());
  if(iceb_sql_readkey(strsql,&row,&cur,data->window) == 1)
   {
    if(atoi(row[0]) == 3)
     {
      sprintf(strsql,"%s %s %s!",gettext("Счёт"),shet_deb.ravno(),gettext("имеет развёрнутое сальдо"));      
      iceb_menu_soob(strsql,data->window);
      continue;      
     }
   }  

  sprintf(strsql,"select saldo from Plansh where ns='%s'",shet_kre.ravno());
  if(iceb_sql_readkey(strsql,&row,&cur,data->window) == 1)
   {
    if(atoi(row[0]) == 3)
     {
      sprintf(strsql,"%s %s %s!",gettext("Счёт"),shet_kre.ravno(),gettext("имеет развёрнутое сальдо"));      
      iceb_menu_soob(strsql,data->window);
      continue;      
     }
   }  

  if(glk_ospsw_r_saldo_sh(shet.ravno(),data->data_s.ravno(),&debet,&kredit,data) != 0)
   continue;
  
  sprintf(strsql,"%s %s",gettext("Обнуление сальдо"),shet.ravno());
  koment.new_plus(strsql);
  
  if(fabs(debet) >= 0.01)
   {
    iceb_zapprov(0,gz,mz,dz,shet.ravno(),shet_deb.ravno(),"","","","","",0.,debet,koment.ravno_filtr(),2,0,time(NULL),0,0,0,0,0,data->window);
    kol_prov++;
   }

  if(fabs(kredit) >= 0.01)
   {
    iceb_zapprov(0,gz,mz,dz,shet.ravno(),shet_kre.ravno(),"","","","","",kredit,0.,koment.ravno_filtr(),2,0,time(NULL),0,0,0,0,0,data->window);
    kol_prov++;
   }
 } 
 
sprintf(strsql,"%s:%d\n",gettext("Количество выполненных проводок"),kol_prov);
iceb_printw(strsql,data->buffer,data->view);

if(kol_prov > 0)
 { 
  sprintf(strsql,"Проводки записаны по дате %02d.%02d.%04d с кометарием \"%s\"\n\%s:%d",
  dz,mz,gz,gettext("Обнуление сальдо"),
  gettext("Количество проводок"),kol_prov);
  iceb_menu_soob(strsql,data->window);
 }





gtk_label_set_text(GTK_LABEL(data->label),gettext("Расчёт закончен"));

data->kon_ras=0;
gtk_widget_set_sensitive(GTK_WIDGET(data->knopka),TRUE);//доступна
gtk_widget_grab_focus(data->knopka);
gtk_widget_show_all(data->window);

iceb_printw_vr(vremn,data->buffer,data->view);

data->voz=0;
return(FALSE);

}
