/*$Id: bsizw.h,v 1.3 2013/08/13 06:09:32 sasa Exp $*/
/*14.04.2020	16.11.2007	Белых А.И.	bsizw.h
Класс для определения балансовой стоимости
*/

class bsizw_data
 {
  public:
    double sbs,siz; //Стартовая балансовая стоимость и износ для налогового учета
    double bs,iz; //Изменения балансовой стоимости и износа для налогового учета
    double iz1; //Амортизация для налогового учёта
    double sbsby,sizby; //Стартовая балансовая стоимость и износ для бух.учёта
    double bsby,izby; //Изменения балансовой стоимости и износа для бух.учёта
    double iz1by; //Амортизация для бух. учёта

    double kbsnu; /*Конечная балансовая стоимость*/
    double kiznu; /*Конечный износ*/

    double kbsbu; /*Конечная балансовая стоимость*/
    double kizbu; /*Конечный износ*/

    double osnu; /*остаточная стоимость (налоговый учёт)*/
    double osbu; /*остаточная стоимость (бух. учёт*/
    
  bsizw_data ()
   {
    clear();
   }
  
  void clear()
   {
    sbs=siz=0.;
    bs=iz=0.;
    iz1=0.;
    sbsby=sizby=0.;
    bsby=izby=0.;
    iz1by=0.;

    kbsnu=kiznu=0.;
    kbsbu=kizbu=0.;

    osnu=osbu=0.;

   }
   
 };
