/*$Id: i_vv_start.c,v 1.5 2013/05/17 14:58:48 sasa Exp $*/
/*22.01.2017	07.09.2007	Белых А.И.	i_vv_start.c
Чтение и выполнение запросов к базе сразу после открытия 
*/
#include <iceb_libbuh.h>

void i_vv_start(const char *imabaz)
{
iceb_start_rf();

}
