/*$I:$*/
/*01.02.2021	01.02.2021	Белых А.И.	zarpkpw.h
*/

class zarpkp_dat
 {
  public:
   class iceb_u_double suma_kp; /*Колонка с суммами начисления квартальной премии*/
   class iceb_u_double suma_kp_mes; /*Колонка с суммами начисления квартальной премии по месяцам в счёт которых она начислена*/

   class iceb_u_spisok kp;   /*номер квартала|год|сумма|дата записи*/
 };
