/*$Id:$*/
/*27.07.2023	27.07.2023	Белых А.И.	glk_ospsw.cpp
Обнуление сальдо по счетам
*/

#include "buhg_g.h"
int glk_ospsw_m(class iceb_u_str *data_s,GtkWidget *wpredok);
int glk_ospsw_r(const char *data_s,GtkWidget *wpredok);

void glk_ospsw(void)
{
static class iceb_u_str data_s("");

if(glk_ospsw_m(&data_s,NULL) != 0)
 return;

glk_ospsw_r(data_s.ravno(),NULL);

}

