/*$Id: sql_rows.c,v 1.3 2013/05/17 14:58:40 sasa Exp $*/
/*30.08.2000	30.08.2000	Белых А.И.	sql_rows.c
Возвращает число строк на которые воздействует последний UPDATE
DELETE или INSERT
ВОЗВРАЩАЕМОЕ ЗНАЧЕНИЕ:
<UL TYPE=DISC><LI>Целое число > 0 показывает число измененных строк.
Ноль, если никакие записи не соответствовали предложению WHERE в
    UPDATE или DELETE.
-1, если запрос возвратил ошибку, например, была сделана попытка
    добавить двойной первичный ключ в течение одного INSERT.
*/
#include	<stdio.h>
#include	"libsql.h"

int		sql_rows(SQL_baza *bd)
{
return(mysql_affected_rows(bd));
}
