/*$Id:$*/
/*01.08.2015	01.08.2015	Белых А.И.	iceb_activate_link.c
Функция реакции на сигнал "activate_link"
*/
#include <gtk/gtk.h>

gboolean iceb_activate_link (GtkWidget   *label,
const gchar *uri,
gpointer     data)
{


return FALSE;
}
