/*$Id:$*/
/*19.04.2021	16.03.2016	Белых А.И.	iceb_get_rtn.c
Взять реквизиты табельного номера
 0-взяли
 1-нет
*/
#include "iceb_libbuh.h"

int iceb_get_rtn(int tabnom,class iceb_fioruk_rk *rek,GtkWidget *wpredok)
{
char strsql[1024];
SQL_str row;
class SQLCURSOR cur;

rek->clear();
if(tabnom <= 0)
 return(1);
 
sprintf(strsql,"select fio,dolg,inn,telef from Kartb where tabn=%d",tabnom);
if(iceb_sql_readkey(strsql,&row,&cur,wpredok) != 1)
 {
  sprintf(strsql,"%s-Не знайден табельный номер %d !",__FUNCTION__,tabnom);
  iceb_menu_soob(strsql,wpredok);
  return(1);
 }
else
 {
  char stroka[512];
  iceb_u_polen(row[0],&rek->famil,1,' ');
  iceb_u_polen(row[0],&rek->ima,2,' ');
  iceb_u_polen(row[0],&rek->oth,3,' ');
  
  sprintf(stroka,"%.*s.%.*s.",
  iceb_u_kolbait(1,rek->ima.ravno()),rek->ima.ravno(),   
  iceb_u_kolbait(1,rek->oth.ravno()),rek->oth.ravno());
  
  strcpy(rek->inic,stroka);

  rek->famil_inic.new_plus(rek->famil.ravno());
  rek->famil_inic.plus(" ",rek->inic);
          
  rek->fio.new_plus(row[0]);
  rek->dolg.new_plus(row[1]);
  rek->inn.new_plus(row[2]);
  
  strncpy(stroka,row[3],sizeof(stroka)-1);
  iceb_u_ud_simv(stroka,"-/.()+,");
       
  rek->telef.new_plus(stroka);
  
  class iceb_u_str Ima("");
  class iceb_u_str FAMIL("");
  /*получаем первый символ имени и преобразовываем его в большой*/  
  memset(stroka,'\0',sizeof(stroka));
  
  g_utf8_strncpy(stroka,rek->ima.ravno(),1);
  iceb_u_toupper_str(stroka);
  Ima.new_plus(stroka);
  
  /*получаем имя без первого символа*/
  g_utf8_strncpy(strsql,iceb_u_adrsimv(1,rek->ima.ravno()),-1);  
  /*преобразовываем в маленькие буквы*/
  iceb_u_tolower_str(strsql);
     
  Ima.plus(strsql);
  
  
  /*Получаем фамилию с большими буквами*/
   strcpy(strsql,rek->famil.ravno());
   iceb_u_toupper_str(strsql);   
   FAMIL.new_plus(strsql);  

   rek->Ima_FAMIL.new_plus(Ima.ravno());
   rek->Ima_FAMIL.plus(" ",FAMIL.ravno());   
 } 

return(0);

}
