/*$Id: iceb_menu_vibknop.h,v 1.2 2011-01-13 13:49:59 sasa Exp $*/
/*05.01.2004	05.01.2004	Белых А.И.	iceb_menu_vibknop.h

*/

class vibknop_data
 {
  public:
  
  GtkWidget *window;
  int       knopka;
 };
