/*$Id: iceb_get_namesystem.c,v 1.2 2013/05/17 14:58:34 sasa Exp $*/
/*19.09.2011	19.09.2011	Белых А.И.	iceb_get_namesystem.c
Получение имени системы
*/
#include "iceb_libbuh.h"

extern char *name_system;

const char *iceb_get_namesystem()
{

return(name_system);

}
