/*$Id: zvb_ibank2ua_endw.c,v 1.6 2013/05/17 14:58:31 sasa Exp $*/
/*14.08.2025	18.09.2008	Белых А.И.	zvb_ibank2ua_endw.c
Концовка формирования данных для зачисления на карт-счета для системы iBank2 UA
*/
#include "buhg_g.h"


void zvb_ibank2ua_endw(const char *imaf_lst,double sumai,
class zvb_menu_lst_r *rm,
FILE *ffr,FILE *ff,GtkWidget *wpredok)
{
short dk=1,mk=rm->mz,gk=rm->gz;
iceb_u_dpm(&dk,&mk,&gk,3);

zvb_end_lstw(imaf_lst,sumai,ffr,wpredok);




//class iceb_u_str shet_bp("29242000000110");

class iceb_u_str shet_bp("");


fprintf(ff,"\
ONFLOW_TYPE=%s\n\
AMOUNT=%.2f\n\
PAYER_BANK_ACCOUNT=%s\n\
VALUE_DATE=%s\n\
CLN_OKPO=%s\n\
ONFLOW_TYPE_ID=%s\n\
BEGIN_MONTH=%02d\n\
BEGIN_YEAR=%d\n\
END_MONTH=%d\n\
END_YEAR=%d\n",
rm->vid_nah.ravno(),
sumai,
shet_bp.ravno(),
"",
rm->edrpou.ravno(),
"",
rm->mz,
rm->gz,
mk,
gk);

fclose(ff);


}
