/*$Id: skopluosw.c,v 1.4 2013/05/17 14:58:27 sasa Exp $*/
/*13.01.2022	12.10.2009	Белых А.И.	skopluosw.c
Получение суммы к оплате для документа учёта основных средств
*/
#include "buhg_g.h"
extern double okrg1;

double skopluosw(short dd,short md,short gd, //Дата документа
const char *nomdok, //номер документа
GtkWidget *wpredok)
{
char strsql[512];
int tipz=0;
double suma=0.;
SQL_str row;
class SQLCURSOR cur;
double pnds=0.;
/*узнаём НДС*/

sprintf(strsql,"select tipz,pn from Uosdok where datd='%04d-%02d-%02d' and nomd='%s'",gd,md,dd,nomdok);
if(iceb_sql_readkey(strsql,&row,&cur,wpredok) <= 0)
 return(0.);
tipz=atoi(row[0]);
pnds=atof(row[1]);
 
sumzapuosw(dd,md,gd,nomdok,&suma,tipz,wpredok);



double nds=suma*pnds/100.;
double suma_dok=suma+nds;

suma_dok=iceb_u_okrug(suma_dok,okrg1);

return(suma_dok);
}
